@@ -3,11 +3,16 @@ import platform
 
 from shoestring_setup.docker import Docker
 from shoestring_setup.shoestring_assembler import Assembler
+from shoestring_setup.apt_deps import InstallAptDependencies
 
 def install(update, force):
 
     os_env = detect_os_env()
-    dependency_classes = {"docker": Docker, "assembler": Assembler}
+    dependency_classes = {
+        "apt": InstallAptDependencies,
+        "docker": Docker,
+        "assembler": Assembler,
+    }
     dependency_instances = [
         dependency_cls(os_env, force) for dependency_cls in dependency_classes.values()
     ]
